==> release.12.0.73.1.tgz: prontus/front/js-local/ProntusCards.js <==
(function (window) {
    let _self = null;
    let Parser =  {
        // Regex patterns.
        patFunction:   /\s*(\w+)\((.*?)\)\s*$/,
        patString1:    /^\s*\'([^\']+)\'\s*$/,
        patString2:    /^\s*\"([^\"]+)\"\s*$/,
        patNumber:     /^\s*([0-9\.eE]+)\s*$/,
        patProntusVar: /^\s*([\w\.\_]+)\s*$/,
        patComparison: /^([\w\"\']+)([ <>!=]+)([\w\"\']+)$/,
        buffer:        "",
        indexpos:      0,
        output: function (buffer, varsObj) {
            Parser.indexpos = 0;
            Parser.buffer = buffer;

            return Parser.methods.parse('start', varsObj);
        },
        methods: {
            parse: function (status, varsObj, statusVars) {
                let resultado = "";
                let condicion;
                let condicionSeCumple;
                let marca;

                switch(status) {
                    case 'start':
                        while (Parser.indexpos < Parser.buffer.length) {
                            var begin = Parser.indexpos;
                            Parser.methods.jumpToNextTag('{{');
                            resultado += Parser.buffer.substring(begin, Parser.indexpos);
                            if (Parser.buffer.substr(Parser.indexpos, 5) == '{{if(') {
                                Parser.indexpos += 5;
                                resultado += Parser.methods.parse('if', varsObj, statusVars);
                            } else if (Parser.buffer.substr(Parser.indexpos, 6) == '{{nif(') {
                                Parser.indexpos += 6;
                                resultado += Parser.methods.parse('nif', varsObj, statusVars);
                            } else if (Parser.buffer.substr(Parser.indexpos, 3) == '{{/') {
                                break;
                            } else if (Parser.buffer.substr(Parser.indexpos, 2) == '{{') {
                                Parser.indexpos += 2;
                                resultado += Parser.methods.parse('tag', varsObj, statusVars);
                            }
                        }

                    break;
                    case 'if':
                        condicion = Parser.methods.getTag(')}}');
                        condicionSeCumple = Parser.methods.conditionParsing(condicion, varsObj, statusVars);
                        if (condicionSeCumple) {
                            resultado += Parser.methods.parse('start', varsObj, statusVars);
                            Parser.methods.endTag('{{/if}}');
                        } else {
                            Parser.methods.ignoreTag('{{if(','{{/if}}');
                        }
                    break;
                    case 'nif':
                        condicion = Parser.methods.getTag(')}}');
                        condicionSeCumple = Parser.methods.conditionParsing(condicion, varsObj, statusVars);

                        if (!condicionSeCumple) {
                            resultado += Parser.methods.parse('start', varsObj, statusVars);
                            Parser.methods.endTag('{{/nif}}');
                        } else {
                            Parser.methods.ignoreTag('{{nif(', '{{/nif}}');
                        }
                    break;
                    case 'tag':
                        marca = Parser.methods.getTag('}}');
                        resultado += Parser.methods.tagParsing(marca, varsObj, statusVars);
                    break;
                }

                return resultado;
            },
            jumpToNextTag: function (tagStr) {
                var len = tagStr.length;
                while ((Parser.buffer.substr(Parser.indexpos, len) != tagStr) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                }
            },
            getTag: function (delimiter) {
                var len = delimiter.length;
                var begin = Parser.indexpos;

                while ((Parser.buffer.substr(Parser.indexpos, len) != delimiter) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                }

                var tagStr = Parser.buffer.substring(begin, Parser.indexpos);

                Parser.indexpos += len;

                return tagStr;
            },
            ignoreTag: function (tagStart, tagEnd) {
                var tagCounter = 1;
                var searching = true;

                while ((tagCounter > 0) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                    if (Parser.buffer.substr(Parser.indexpos, tagStart.length) == tagStart) {
                        tagCounter++;
                        Parser.indexpos += tagStart.length;
                    } else if (Parser.buffer.substr(Parser.indexpos, tagEnd.length) == tagEnd) {
                        tagCounter--;
                        Parser.indexpos += tagEnd.length;
                    }
                }
            },
            endTag: function (tagEnd) {
                if (Parser.buffer.substr(Parser.indexpos, tagEnd.length) == tagEnd) {
                    Parser.indexpos += tagEnd.length;
                }
            },
            paramParsing: function (paramTxt, varsObj, statusVars) {
                var paramArray = paramTxt.split(',');
                var resArray = [];
                var i;

                for (i = 0; i < paramArray.length; i++) {
                    resArray[i] = Parser.methods.tagParsing(paramArray[i], varsObj, statusVars);
                }

                return resArray;
            },
            functionParsing: function (tag, varsObj, statusVars) {
                var functionComponents = tag.match(Parser.patFunction);
                var res = null;

                if (functionComponents !== null) {
                    var funcion = functionComponents[1];
                    var parametros = [];

                    parametros = Parser.methods.paramParsing(functionComponents[2], varsObj, statusVars);

                    try {
                        res = _ParserFN.prontusFN[funcion](parametros);
                    } catch(err){
                        //console.log('ERROR: ' + err);
                    }
                }

                return res;
            },
            tagParsing: function (tag, varsObj, statusVars) {
                var value = null;
                var i;

                // console.log("tag", tag);

                if (tag.search(Parser.patFunction) === 0) {
                    // Funcion.
                    value = Parser.methods.functionParsing(tag, varsObj, statusVars);
                } else if (tag.search(Parser.patString2) === 0) {
                    matching = tag.match(Parser.patString2);
                    value = String(matching[1]);
                } else if (tag.search(Parser.patString1) === 0) {
                    matching = tag.match(Parser.patString1);
                    value = String(matching[1]);
                } else if (tag.search(Parser.patNumber) === 0) {
                    matching = tag.match(Parser.patNumber);
                    value = Number(matching[1]);
                } else if (tag.search(Parser.patProntusVar) === 0) {
                    matching = tag.match(Parser.patProntusVar);
                    tag = matching[1];

                    if (tag.substr(0,5) == '_loop') {
                        value = statusVars[tag];
                        if (tag == '_loopInc') {
                            statusVars[tag]++;
                        }
                    } else {
                        value = varsObj[tag];
                    }
                }

                return value;
            },
            conditionParsing: function (condicion ,varsObj, statusVars) {
                var condicionSeCumple = false;

                if (condicion.search(Parser.patProntusVar) === 0) {
                    var valor = Parser.methods.tagParsing(condicion, varsObj, statusVars);

                    if (valor !== null) {
                        condicionSeCumple = true;
                    }

                } else if (condicion.search(Parser.patFunction) === 0) {
                    condicionSeCumple = Parser.methods.functionParsing(condicion, varsObj, statusVars);
                } else if (condicion.search(Parser.patComparison) === 0) {
                    var opr = condicion.match(Parser.patComparison);
                    var opr1 = String(opr[1]);
                    var comparador = String(opr[2]);
                    var opr2 = String(opr[3]);

                    opr1 = Parser.methods.tagParsing(opr1, varsObj, statusVars);
                    opr2 = Parser.methods.tagParsing(opr2, varsObj, statusVars);

                    if (comparador.search('==') >= 0) {
                        condicionSeCumple = (opr1 == opr2);
                    } else if (comparador.search('!=') >= 0) {
                        condicionSeCumple = (opr1 != opr2);
                    } else if (comparador.search('>=') >= 0) {
                        condicionSeCumple = (opr1 >= opr2);
                    } else if (comparador.search('<=') >= 0) {
                        condicionSeCumple = (opr1 <= opr2);
                    } else if (comparador.search('<') >= 0) {
                        condicionSeCumple = (opr1 < opr2);
                    } else if (comparador.search('>') >= 0) {
                        condicionSeCumple = (opr1 > opr2);
                    }
                }

                return condicionSeCumple;
            }
        }
    };
    let ProntusCards = {
        init: function () {
            _self = this;
            _self.methods.findProntusCards();
        },
        methods: {
            findProntusCards: function () {
                let list = document.querySelectorAll(".prontus-card-content");

                for (let x = 0; x < list.length; x++) {
                    let card = list[x];
                    let cardTs = card.getAttribute("data-ts");
                    let cardUrl = card.getAttribute("data-url");

                    if (cardTs) {
                        let fechadir = cardTs.substring(0, 8);
                        let cardProntus = card.getAttribute("data-prontus-id");
                        let articJsonUrl = `/${cardProntus}/site/artic/${fechadir}/json/${cardTs}.json`;

                        Dom.ajaxRequest({
                            url: articJsonUrl + "?" + (new Date()).getTime(),
                            dataType: "json",
                            success: function (response) {
                                if (response) {
                                    _self.methods.parseProntusCard(card, response);
                                }
                            }
                        });
                    } else if (cardUrl) {
                        let data = JSON.parse(card.getAttribute("data-data"));

                        console.log(data);
                        _self.methods.parseProntusCard(card, data);

                    }
                }
            },
            parseProntusCard: function (card, articData) {
                let articKeys = Object.keys(articData);
                let cardHtml = card.innerHTML;

                cardHtml = Parser.output(cardHtml, articData);

                card.innerHTML = cardHtml;
                card.style.display = "block";

                let scriptElements = Array.from(card.getElementsByTagName("script"));

                for (let item of scriptElements) {
                    let code = item.innerHTML;

                    item.remove();

                    let newScript = document.createElement("script");
                    newScript.type = "text/javascript";
                    newScript.innerHTML = code;

                    card.appendChild(newScript);
                }
            }
        }
    };
    let Dom = {
        documentReady: function(callback) {
            if (document.attachEvent) {
                document.attachEvent("onreadystatechange", function() {
                    if (document.readyState === "complete") {
                        return callback();
                    }
                });
            } else {
                document.addEventListener('DOMContentLoaded', callback);
            }
        },
        ajaxRequest: function(options) {
            var request = new XMLHttpRequest();

            if (typeof options.dataType == 'undefined') {
                options.dataType = 'text';
            }

            if (typeof options.data == 'undefined') {
                options.data = {};
            }

            request.onreadystatechange = function() {
                // loading.
                if (request.readyState < 4) {
                    return;
                }

                // console.log('request status', request.status);

                // error.
                if (request.status !== 200) {
                    if (typeof options.error == 'function') {
                        options.error(request.statusText);
                    }
                    // return;
                }

                // success.
                if (request.readyState === 4 && request.status === 200) {
                    if (typeof options.success == 'function') {
                        if (options.dataType == 'json') {
                            let json;

                            try {
                                json = JSON.parse(request.responseText)
                            } catch (e) {
                                json = false;
                            }

                            options.success(json);
                        } else {
                            options.success(request.responseText);
                        }
                    }
                }
            };

            request.ontimeout = function (e) {
                console.error("url timeout", options.url);
                if (typeof options.error == 'function') {
                    options.error(e, "timeout");
                }
            };

            var method = 'GET';

            if (typeof options.method != 'undefined') {
                method = options.method;
            }

            request.timeout = 1000 * 60; // 1 minuto.
            request.open(method, options.url, true);
            // request.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');

            var formData = new FormData();
            var dataKeys = Object.keys(options.data);

            for (var x = 0; x < dataKeys.length; x++) {
                formData.append(dataKeys[x], options.data[dataKeys[x]]);
            }

            request.send(formData);
        }
    };

    Dom.documentReady(function () {
        ProntusCards.init();
    });
})(this);

==> release.12.3.1.2.tgz: prontus/front/js-local/ProntusCards.js <==
(function (window) {
    let _self = null;
    let Parser =  {
        // Regex patterns.
        patFunction:   /\s*(\w+)\((.*?)\)\s*$/,
        patString1:    /^\s*\'([^\']+)\'\s*$/,
        patString2:    /^\s*\"([^\"]+)\"\s*$/,
        patNumber:     /^\s*([0-9\.eE]+)\s*$/,
        patProntusVar: /^\s*([\w\.\_]+)\s*$/,
        patComparison: /^([\w\"\']+)([ <>!=]+)([\w\"\']+)$/,
        buffer:        "",
        indexpos:      0,
        output: function (buffer, varsObj) {
            Parser.indexpos = 0;
            Parser.buffer = buffer;

            return Parser.methods.parse('start', varsObj);
        },
        methods: {
            parse: function (status, varsObj, statusVars) {
                let resultado = "";
                let condicion;
                let condicionSeCumple;
                let marca;

                switch(status) {
                    case 'start':
                        while (Parser.indexpos < Parser.buffer.length) {
                            var begin = Parser.indexpos;
                            Parser.methods.jumpToNextTag('{{');
                            resultado += Parser.buffer.substring(begin, Parser.indexpos);
                            if (Parser.buffer.substr(Parser.indexpos, 5) == '{{if(') {
                                Parser.indexpos += 5;
                                resultado += Parser.methods.parse('if', varsObj, statusVars);
                            } else if (Parser.buffer.substr(Parser.indexpos, 6) == '{{nif(') {
                                Parser.indexpos += 6;
                                resultado += Parser.methods.parse('nif', varsObj, statusVars);
                            } else if (Parser.buffer.substr(Parser.indexpos, 3) == '{{/') {
                                break;
                            } else if (Parser.buffer.substr(Parser.indexpos, 2) == '{{') {
                                Parser.indexpos += 2;
                                resultado += Parser.methods.parse('tag', varsObj, statusVars);
                            }
                        }

                    break;
                    case 'if':
                        condicion = Parser.methods.getTag(')}}');
                        condicionSeCumple = Parser.methods.conditionParsing(condicion, varsObj, statusVars);
                        if (condicionSeCumple) {
                            resultado += Parser.methods.parse('start', varsObj, statusVars);
                            Parser.methods.endTag('{{/if}}');
                        } else {
                            Parser.methods.ignoreTag('{{if(','{{/if}}');
                        }
                    break;
                    case 'nif':
                        condicion = Parser.methods.getTag(')}}');
                        condicionSeCumple = Parser.methods.conditionParsing(condicion, varsObj, statusVars);

                        if (!condicionSeCumple) {
                            resultado += Parser.methods.parse('start', varsObj, statusVars);
                            Parser.methods.endTag('{{/nif}}');
                        } else {
                            Parser.methods.ignoreTag('{{nif(', '{{/nif}}');
                        }
                    break;
                    case 'tag':
                        marca = Parser.methods.getTag('}}');
                        resultado += Parser.methods.tagParsing(marca, varsObj, statusVars);
                    break;
                }

                return resultado;
            },
            jumpToNextTag: function (tagStr) {
                var len = tagStr.length;
                while ((Parser.buffer.substr(Parser.indexpos, len) != tagStr) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                }
            },
            getTag: function (delimiter) {
                var len = delimiter.length;
                var begin = Parser.indexpos;

                while ((Parser.buffer.substr(Parser.indexpos, len) != delimiter) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                }

                var tagStr = Parser.buffer.substring(begin, Parser.indexpos);

                Parser.indexpos += len;

                return tagStr;
            },
            ignoreTag: function (tagStart, tagEnd) {
                var tagCounter = 1;
                var searching = true;

                while ((tagCounter > 0) && (Parser.indexpos < Parser.buffer.length)) {
                    Parser.indexpos++;
                    if (Parser.buffer.substr(Parser.indexpos, tagStart.length) == tagStart) {
                        tagCounter++;
                        Parser.indexpos += tagStart.length;
                    } else if (Parser.buffer.substr(Parser.indexpos, tagEnd.length) == tagEnd) {
                        tagCounter--;
                        Parser.indexpos += tagEnd.length;
                    }
                }
            },
            endTag: function (tagEnd) {
                if (Parser.buffer.substr(Parser.indexpos, tagEnd.length) == tagEnd) {
                    Parser.indexpos += tagEnd.length;
                }
            },
            paramParsing: function (paramTxt, varsObj, statusVars) {
                var paramArray = paramTxt.split(',');
                var resArray = [];
                var i;

                for (i = 0; i < paramArray.length; i++) {
                    resArray[i] = Parser.methods.tagParsing(paramArray[i], varsObj, statusVars);
                }

                return resArray;
            },
            functionParsing: function (tag, varsObj, statusVars) {
                var functionComponents = tag.match(Parser.patFunction);
                var res = null;

                if (functionComponents !== null) {
                    var funcion = functionComponents[1];
                    var parametros = [];

                    parametros = Parser.methods.paramParsing(functionComponents[2], varsObj, statusVars);

                    try {
                        res = _ParserFN.prontusFN[funcion](parametros);
                    } catch(err){
                        //console.log('ERROR: ' + err);
                    }
                }

                return res;
            },
            tagParsing: function (tag, varsObj, statusVars) {
                var value = null;
                var i;

                // console.log("tag", tag);

                if (tag.search(Parser.patFunction) === 0) {
                    // Funcion.
                    value = Parser.methods.functionParsing(tag, varsObj, statusVars);
                } else if (tag.search(Parser.patString2) === 0) {
                    matching = tag.match(Parser.patString2);
                    value = String(matching[1]);
                } else if (tag.search(Parser.patString1) === 0) {
                    matching = tag.match(Parser.patString1);
                    value = String(matching[1]);
                } else if (tag.search(Parser.patNumber) === 0) {
                    matching = tag.match(Parser.patNumber);
                    value = Number(matching[1]);
                } else if (tag.search(Parser.patProntusVar) === 0) {
                    matching = tag.match(Parser.patProntusVar);
                    tag = matching[1];

                    if (tag.substr(0,5) == '_loop') {
                        value = statusVars[tag];
                        if (tag == '_loopInc') {
                            statusVars[tag]++;
                        }
                    } else {
                        value = varsObj[tag];
                    }
                }

                return value;
            },
            conditionParsing: function (condicion ,varsObj, statusVars) {
                var condicionSeCumple = false;

                if (condicion.search(Parser.patProntusVar) === 0) {
                    var valor = Parser.methods.tagParsing(condicion, varsObj, statusVars);

                    if (valor !== null) {
                        condicionSeCumple = true;
                    }

                } else if (condicion.search(Parser.patFunction) === 0) {
                    condicionSeCumple = Parser.methods.functionParsing(condicion, varsObj, statusVars);
                } else if (condicion.search(Parser.patComparison) === 0) {
                    var opr = condicion.match(Parser.patComparison);
                    var opr1 = String(opr[1]);
                    var comparador = String(opr[2]);
                    var opr2 = String(opr[3]);

                    opr1 = Parser.methods.tagParsing(opr1, varsObj, statusVars);
                    opr2 = Parser.methods.tagParsing(opr2, varsObj, statusVars);

                    if (comparador.search('==') >= 0) {
                        condicionSeCumple = (opr1 == opr2);
                    } else if (comparador.search('!=') >= 0) {
                        condicionSeCumple = (opr1 != opr2);
                    } else if (comparador.search('>=') >= 0) {
                        condicionSeCumple = (opr1 >= opr2);
                    } else if (comparador.search('<=') >= 0) {
                        condicionSeCumple = (opr1 <= opr2);
                    } else if (comparador.search('<') >= 0) {
                        condicionSeCumple = (opr1 < opr2);
                    } else if (comparador.search('>') >= 0) {
                        condicionSeCumple = (opr1 > opr2);
                    }
                }

                return condicionSeCumple;
            }
        }
    };
    let ProntusCards = {
        init: function () {
            _self = this;
            _self.methods.findProntusCards();
        },
        methods: {
            findProntusCards: function () {
                let list = document.querySelectorAll(".prontus-card-content");

                for (let x = 0; x < list.length; x++) {
                    let card = list[x];
                    let cardTs = card.getAttribute("data-ts");
                    let cardUrl = card.getAttribute("data-url");

                    if (cardTs) {
                        let fechadir = cardTs.substring(0, 8);
                        let cardProntus = card.getAttribute("data-prontus-id");
                        let articJsonUrl = `/${cardProntus}/site/artic/${fechadir}/json/${cardTs}.json`;

                        Dom.ajaxRequest({
                            url: articJsonUrl + "?" + Date.now(),
                            dataType: "json",
                            success: function (response) {
                                if (response) {
                                    _self.methods.parseProntusCard(card, response);
                                }
                            }
                        });
                    } else if (cardUrl) {
                        let data = JSON.parse(card.getAttribute("data-data"));

                        console.log(data);
                        _self.methods.parseProntusCard(card, data);

                    }
                }
            },
            parseProntusCard: function (card, articData) {
                let articKeys = Object.keys(articData);
                let cardHtml = card.innerHTML;

                cardHtml = Parser.output(cardHtml, articData);

                card.innerHTML = cardHtml;
                card.style.display = "block";

                let scriptElements = Array.from(card.getElementsByTagName("script"));

                for (let item of scriptElements) {
                    let code = item.innerHTML;

                    item.remove();

                    let newScript = document.createElement("script");
                    newScript.type = "text/javascript";
                    newScript.innerHTML = code;

                    card.appendChild(newScript);
                }
            }
        }
    };
    let Dom = {
        documentReady: function(callback) {
            if (document.attachEvent) {
                document.attachEvent("onreadystatechange", function() {
                    if (document.readyState === "complete") {
                        return callback();
                    }
                });
            } else {
                document.addEventListener('DOMContentLoaded', callback);
            }
        },
        ajaxRequest: function(options) {
            var request = new XMLHttpRequest();

            if (typeof options.dataType == 'undefined') {
                options.dataType = 'text';
            }

            if (typeof options.data == 'undefined') {
                options.data = {};
            }

            request.onreadystatechange = function() {
                // loading.
                if (request.readyState < 4) {
                    return;
                }

                // console.log('request status', request.status);

                // error.
                if (request.status !== 200) {
                    if (typeof options.error == 'function') {
                        options.error(request.statusText);
                    }
                    // return;
                }

                // success.
                if (request.readyState === 4 && request.status === 200) {
                    if (typeof options.success == 'function') {
                        if (options.dataType == 'json') {
                            let json;

                            try {
                                json = JSON.parse(request.responseText)
                            } catch (e) {
                                json = false;
                            }

                            options.success(json);
                        } else {
                            options.success(request.responseText);
                        }
                    }
                }
            };

            request.ontimeout = function (e) {
                console.error("url timeout", options.url);
                if (typeof options.error == 'function') {
                    options.error(e, "timeout");
                }
            };

            var method = 'GET';

            if (typeof options.method != 'undefined') {
                method = options.method;
            }

            request.timeout = 1000 * 60; // 1 minuto.
            request.open(method, options.url, true);
            // request.setRequestHeader('Content-type', 'application/x-www-form-urlencoded');

            var formData = new FormData();
            var dataKeys = Object.keys(options.data);

            for (var x = 0; x < dataKeys.length; x++) {
                formData.append(dataKeys[x], options.data[dataKeys[x]]);
            }

            request.send(formData);
        }
    };

    window.ProntusCards = ProntusCards;
    Dom.documentReady(function () {
        ProntusCards.init();
    });
})(this);
